/*
   ODBCLoginPanel.m

   Copyright (c) 1996, 1998 Apple Computer Software, Inc.
   All rights reserved.

   IMPORTANT:  This Apple software is supplied to you in consideration of your agreement
   to the terms of the Apple Software License Agreement stated in the file ODBC_LICENSE.rtf
   provided with the software.  Your use of the software is governed by such terms.
   Do not use, install, or make copies of the software if you do not agree to such terms.

   THIS SOFTWARE IS FURNISHED ON AN "AS-IS" BASIS. APPLE MAKES NO WARRANTIES OF ANY KIND,
   EITHER EXPRESS OR IMPLIED, AS TO ANY MATTER WHATSOEVER, INCLUDING WITHOUT LIMITATION
   THE CONDITION, MERCHANTABILITY, OR FITNESS FOR ANY PARTICULAR PURPOSE OF THIS SOFTWARE.
   APPLE DOES NOT ASSUME ANY LIABILITY REGARDING USE OF, OR ANY DEFECT IN, THIS SOFTWARE.
   IN NO EVENT SHALL APPLE BE LIABLE FOR ANY INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
   DAMAGES, EVEN IF IT HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#import "ODBCLoginPanel.h"
#import "../ODBCprivate.h"

#import <AppKit/AppKit.h>

@implementation ODBCLoginPanel

extern const char ODBC_VERS_NUM[];

- init
{
#if 0
#warning Where should I show the version number ?
    NSString *versionString = [NSString stringWithCString:ODBC_VERS_NUM];


    if(!versionString || ![versionString length]) {
        versionString = @"Development version";
    } else {
        versionString = [NSString stringWithFormat:@"v.%@", versionString];
    }

   // [??? setTitle:[NSString stringWithFormat:@"%@ (%@)", [window title], versionString]];
#endif
    
    [super init];

    return self;
}

- (NSDictionary *)runPanelForAdaptor:(EOAdaptor *)adaptor validate:(BOOL)validate
{
    NSDictionary *result = nil;

    NS_DURING
        NSAutoreleasePool *pool = [NSAutoreleasePool new];
        ODBCContext *context;
        NSMutableDictionary *newConnectionDictionary;
        NSString *connectionString;

        if(![adaptor connectionDictionary]) {
            [adaptor setConnectionDictionary:[NSDictionary dictionary]];
        }
        
        //
        // Create a context
        //
        context = (ODBCContext *)[adaptor createAdaptorContext];

        //
        // Connect to the database using the set of ODBC panels
        // then disconnect
        //
        connectionString = [context odbcConnectWithWindowsHandle:[[NSApp mainWindow] windowHandle]];
        [context odbcDisconnect];

        //
        // Build the new connection dictionary
        //
        newConnectionDictionary = [[[adaptor connectionDictionary] mutableCopy] autorelease];

        [newConnectionDictionary setObject:connectionString forKey:connectionStringKey];

        [adaptor setConnectionDictionary:newConnectionDictionary];
        [pool release];

        //
        // Make sure it's working
        //
        if(validate)
            [adaptor assertConnectionDictionaryIsValid];

        result = [adaptor connectionDictionary];
    NS_HANDLER
        NSRunAlertPanel (NULL, @"%@", NULL, NULL, NULL, [localException reason]);
    NS_ENDHANDLER

    //
    // Returns it.
    //
    return result;
}

@end
