/*
   ODBCPrivate.h
   Copyright (c) 1996, 1998 Apple Computer, Inc.
   All rights reserved.
*/

#import <ODBCEOAdaptor/ODBCAdaptor.h>
#import <ODBCEOAdaptor/ODBCContext.h>
#import <ODBCEOAdaptor/ODBCChannel.h>
#import <ODBCEOAdaptor/ODBCColumn.h>
#import <ODBCEOAdaptor/ODBCSQLExpression.h>

// This header file imports the appropriate headers from the Microsoft
// ODBC 3.0 SDK. Apple does not redistribute the ODBC SDK, but it is
// available directly from Microsoft.  <http://www.microsoft.com/data/odbc/>.
//
// ODBC headers are not self contained: you need to include windows.h
// before. Since the only type used is the window handle (HWND) we
// just fake it right here. By doing so, we avoid dependencies and
// Makefile problems.
//
#define HWND void *

// EOF_ODBC can be used to customize other headers.  The ODBC 3.0 SDK headers
// had a couple of minor problems, so we used #ifndef EOF_ODBC to skip the
// lines with problems.
#define EOF_ODBC

// The ODBC adaptor was written to the ODBC SDK 2.5 specification.  We define
// ODBCVER here so that ODBC SDK 3.0 headers should be backward compatible.
#define ODBCVER 0x0250

// This import is specific to ODBC on the solaris platform. uncomment if you need it.
// #import "sqlcli1.h"

#import "sql.h"
#import "sqlext.h"

// DB2 include file do not define SQL_TYPE_NULL
#ifndef SQL_TYPE_NULL
#define SQL_TYPE_NULL 0
#endif



@interface ODBCContext(_ODBCErrorNotification)
- (NSArray *)odbcErrorWithChannel:(ODBCChannel *)channel string:(NSString *)location raise:(BOOL)flag;
- (NSArray *)odbcErrorWithChannel:(ODBCChannel *)channel sender:(id)sender methodName:(NSString *)methodName functionName:(NSString *)functionName raise:(BOOL)flag;
    // Returns an array of SQLState strings.
  
- (NSString *)odbcConnectWithWindowsHandle:(void *)windowHandle;
    // Popup the standard ODBC login panel and returns a new connection string
@end

@interface ODBCAdaptor(_ODBCPrivate)
- (EOAttribute *)attributeWithName:(NSString *)name columnName:(NSString *)columnName externalType:(NSString *)externalType odbcType:(int)odbcType length:(int)length precision:(int)precision scale:(int)scale nullable:(BOOL)nullable;
@end

@interface EOAttribute(_ODBCPrivate)
- (int)odbcType;
- (NSString *)odbcTypeString;
@end

//
// These are some useful private EOF methods.
// All these methods are trivial to implement.
// These are subject to change in future releases of EOF so
// use them with care.
//
@interface EOEntity (_ODBCPrivate)
- (EOAttribute *)attributeForPath:(NSString *)attributePath;
- (EORelationship *)relationshipForPath:(NSString *)relationshipPath;
@end

@interface NSString (_ODBCPrivate)
- (NSString *)relationshipPathByDeletingLastComponent;
@end

@interface EOSQLExpression (_ODBCPrivate)
- (NSString *)_aliasForRelatedAttribute:(EOAttribute *)attribute relationshipPath:(NSString *)relationshipPath;
@end


